module Data.Text.Prettyprint.Doc.Render.ShowS {-# DEPRECATED "Use Data.Text.Prettyprint.Doc.Render.String instead" #-} (
    renderShowS
) where

import Data.Text.Prettyprint.Doc.Internal (renderShowS)
